API Reference
==============

.. toctree::
    :maxdepth: 4

    yellowbrick
    yellowbrick.features
    yellowbrick.regressor
    yellowbrick.classifier
    yellowbrick.cluster
    yellowbrick.text
    yellowbrick.style
